@@ -22,7 +22,8 @@ use strict;
 use warnings;
 no warnings 'uninitialized';
 
-use Encode::compat;
+BEGIN { require Encode::compat if $] < 5.007001 }
+
 use Encode qw(encode);
 
 =head2 new
